@@ -42,8 +42,10 @@ class DownloadUtil extends BroadcastReceiver {
   }
 
   static void Deinitialise(Context context) {
-    context.unregisterReceiver(instance);
-    instance = null;
+    if (instance != null) {
+      context.unregisterReceiver(instance);
+      instance = null;
+    }
   }
 
   /**
@@ -162,6 +164,10 @@ class DownloadUtil extends BroadcastReceiver {
                             DownloadManager.STATUS_SUCCESSFUL);
     Cursor c = dm.query(query);
 
+    if (c == null)
+      /* should not happen, but has been observed on Android 2.3 */
+      return;
+
     if (!c.moveToFirst())
       return;
 
