@@ -25,9 +25,12 @@ Copyright_License {
 #include "Profile/Profile.hpp"
 #include "OS/Args.hpp"
 #include "OS/ConvertPathName.hpp"
-#include "Hardware/Display.hpp"
+#include "Hardware/DisplayDPI.hpp"
 #include "Simulator.hpp"
 #include "LocalPath.hpp"
+#include "Util/CharUtil.hpp"
+#include "Util/NumberParser.hpp"
+#include "Asset.hpp"
 
 #ifdef WIN32
 #include <windows.h> /* for AllocConsole() */
@@ -35,16 +38,13 @@ Copyright_License {
 
 namespace CommandLine {
 #if !defined(_WIN32_WCE)
-  unsigned width = 640, height = 480;
+  unsigned width = IsKobo() ? 600 : 640;
+  unsigned height = IsKobo() ? 800 : 480;
 #endif
 
 #ifdef HAVE_CMDLINE_FULLSCREEN
   bool full_screen = false;
 #endif
-
-#ifdef HAVE_CMDLINE_RESIZABLE
-  bool resizable = false;
-#endif
 }
 
 void
@@ -87,11 +87,13 @@ CommandLine::Parse(Args &args)
 #if !defined(_WIN32_WCE)
     else if (isdigit(s[1])) {
       char *p;
-      width = strtol(s+1, &p, 10);
+      width = ParseUnsigned(s + 1, &p);
       if (*p != 'x' && *p != 'X')
         args.UsageError();
       s = p;
-      height = strtol(s+1, &p, 10);
+      height = ParseUnsigned(s + 1, &p);
+      if (*p != '\0')
+        args.UsageError();
     }
     else if (strcmp(s, "-portrait") == 0) {
       width = 480;
@@ -111,11 +113,6 @@ CommandLine::Parse(Args &args)
       full_screen = true;
     }
 #endif
-#ifdef HAVE_CMDLINE_RESIZABLE
-    else if (strcmp(s, "-resizable") == 0) {
-      resizable = true;
-    }
-#endif
 #if defined(_WIN32) && !defined(_WIN32_WCE) && !defined(__WINE__)
     else if (strcmp(s, "-console") == 0) {
       AllocConsole();
@@ -126,12 +123,14 @@ CommandLine::Parse(Args &args)
     else if (strncmp(s, "-dpi=", 5) == 0) {
       unsigned x_dpi, y_dpi;
       char *p;
-      x_dpi = strtol(s+5, &p, 10);
+      x_dpi = ParseUnsigned(s + 5, &p);
       if (*p == 'x' || *p == 'X') {
         s = p;
-        y_dpi = strtol(s+1, &p, 10);
+        y_dpi = ParseUnsigned(s + 1, &p);
       } else
         y_dpi = x_dpi;
+      if (*p != '\0')
+        args.UsageError();
 
       if (x_dpi < 32 || x_dpi > 512 || y_dpi < 32 || y_dpi > 512)
         args.UsageError();
