@@ -25,7 +25,7 @@ Copyright_License {
 #include "Profile/ProfileKeys.hpp"
 #include "Profile/Profile.hpp"
 #include "Form/DataField/Enum.hpp"
-#include "Hardware/Display.hpp"
+#include "Hardware/RotateDisplay.hpp"
 #include "Interface.hpp"
 #include "MainWindow.hpp"
 #include "LogFile.hpp"
@@ -34,6 +34,12 @@ Copyright_License {
 #include "Widget/RowFormWidget.hpp"
 #include "UIGlobals.hpp"
 #include "UtilsSettings.hpp"
+#include "Asset.hpp"
+
+#ifdef KOBO
+#include "Event/Globals.hpp"
+#include "Event/Queue.hpp"
+#endif
 
 enum ControlIndex {
   DisplayOrientation,
@@ -41,7 +47,6 @@ enum ControlIndex {
   AppFlarmLocation,
   TabDialogStyle,
   AppStatusMessageAlignment,
-  DialogStyle,
   AppInverseInfoBox,
   AppInfoBoxColors,
   AppInfoBoxBorder
@@ -62,44 +67,32 @@ static constexpr StaticEnumChoice display_orientation_list[] = {
 };
 
 static constexpr StaticEnumChoice info_box_geometry_list[] = {
-  { (unsigned)InfoBoxSettings::Geometry::TOP_4_BOTTOM_4,
-    N_("8 Top + Bottom (Portrait)") },
-  { (unsigned)InfoBoxSettings::Geometry::BOTTOM_8,
-    N_("8 Bottom (Portrait)") },
+  { (unsigned)InfoBoxSettings::Geometry::SPLIT_8,
+    N_("8 Split") },
+  { (unsigned)InfoBoxSettings::Geometry::BOTTOM_RIGHT_8,
+    N_("8 Bottom or Right") },
   { (unsigned)InfoBoxSettings::Geometry::BOTTOM_8_VARIO,
     N_("8 Bottom + Vario (Portrait)") },
-  { (unsigned)InfoBoxSettings::Geometry::TOP_8,
-    N_("8 Top (Portrait)") },
+  { (unsigned)InfoBoxSettings::Geometry::TOP_LEFT_8,
+    N_("8 Top or Left") },
   { (unsigned)InfoBoxSettings::Geometry::TOP_8_VARIO,
     N_("8 Top + Vario (Portrait)") },
-  { (unsigned)InfoBoxSettings::Geometry::LEFT_4_RIGHT_4,
-    N_("8 Left + Right (Landscape)") },
-  { (unsigned)InfoBoxSettings::Geometry::LEFT_8,
-    N_("8 Left (Landscape)") },
-  { (unsigned)InfoBoxSettings::Geometry::RIGHT_8,
-    N_("8 Right (Landscape)") },
   { (unsigned)InfoBoxSettings::Geometry::RIGHT_9_VARIO,
     N_("9 Right + Vario (Landscape)") },
   { (unsigned)InfoBoxSettings::Geometry::LEFT_6_RIGHT_3_VARIO,
     N_("9 Left + Right + Vario (Landscape)") },
   { (unsigned)InfoBoxSettings::Geometry::RIGHT_5,
     N_("5 Right (Square)") },
-  { (unsigned)InfoBoxSettings::Geometry::RIGHT_12,
-    N_("12 Right (Landscape)") },
-  { (unsigned)InfoBoxSettings::Geometry::BOTTOM_12,
-    N_("12 Bottom (Portrait)") },
-  { (unsigned)InfoBoxSettings::Geometry::TOP_12,
-    N_("12 Top (Portrait)") },
+  { (unsigned)InfoBoxSettings::Geometry::BOTTOM_RIGHT_12,
+    N_("12 Bottom or Right") },
+  { (unsigned)InfoBoxSettings::Geometry::TOP_LEFT_12,
+    N_("12 Top or Left") },
   { (unsigned)InfoBoxSettings::Geometry::RIGHT_24,
     N_("24 Right (Landscape)") },
-  { (unsigned)InfoBoxSettings::Geometry::TOP_4,
-    N_("4 Top (Portrait)") },
-  { (unsigned)InfoBoxSettings::Geometry::BOTTOM_4,
-    N_("4 Bottom (Portrait)") },
-  { (unsigned)InfoBoxSettings::Geometry::LEFT_4,
-    N_("4 Left (Landscape)") },
-  { (unsigned)InfoBoxSettings::Geometry::RIGHT_4,
-    N_("4 Right (Landscape)") },
+  { (unsigned)InfoBoxSettings::Geometry::TOP_LEFT_4,
+    N_("4 Top or Left") },
+  { (unsigned)InfoBoxSettings::Geometry::BOTTOM_RIGHT_4,
+    N_("4 Bottom or Right") },
   { 0 }
 };
 
@@ -137,14 +130,6 @@ static constexpr StaticEnumChoice popup_msg_position_list[] = {
   { 0 }
 };
 
-static constexpr StaticEnumChoice dialog_style_list[] = {
-  { 0, N_("Full width") },
-  { 1, N_("Scaled") },
-  { 2, N_("Scaled centered") },
-  { 3, N_("Fixed") },
-  { 0 }
-};
-
 static constexpr StaticEnumChoice infobox_border_list[] = {
   { unsigned(InfoBoxSettings::BorderStyle::BOX),
     N_("Box"), N_("Draws boxes around each InfoBox.") },
@@ -197,19 +182,18 @@ LayoutConfigPanel::Prepare(ContainerWindow &parent, const PixelRect &rc)
           (unsigned)ui_settings.popup_message_position);
   SetExpertRow(AppStatusMessageAlignment);
 
-  AddEnum(_("Dialog size"), _("Choose the display size of dialogs."),
-          dialog_style_list, ui_settings.dialog.dialog_style);
-  SetExpertRow(DialogStyle);
-
   AddBoolean(_("Inverse InfoBoxes"), _("If true, the InfoBoxes are white on black, otherwise black on white."),
              ui_settings.info_boxes.inverse);
   SetExpertRow(AppInverseInfoBox);
 
-  AddBoolean(_("Colored InfoBoxes"),
-             _("If true, certain InfoBoxes will have coloured text.  For example, the active waypoint "
+  if (HasColors()) {
+    AddBoolean(_("Colored InfoBoxes"),
+               _("If true, certain InfoBoxes will have coloured text.  For example, the active waypoint "
                  "InfoBox will be blue when the glider is above final glide."),
-             ui_settings.info_boxes.use_colors);
-  SetExpertRow(AppInfoBoxColors);
+               ui_settings.info_boxes.use_colors);
+    SetExpertRow(AppInfoBoxColors);
+  } else
+    AddDummy();
 
   AddEnum(_("InfoBox border"), nullptr, infobox_border_list,
           unsigned(ui_settings.info_boxes.border_style));
@@ -247,9 +231,6 @@ LayoutConfigPanel::Save(bool &_changed)
   changed |= SaveValueEnum(AppStatusMessageAlignment, ProfileKeys::AppStatusMessageAlignment,
                            ui_settings.popup_message_position);
 
-  changed |= SaveValueEnum(DialogStyle, ProfileKeys::AppDialogStyle,
-                           ui_settings.dialog.dialog_style);
-
   changed |= SaveValueEnum(AppInfoBoxBorder, ProfileKeys::AppInfoBoxBorder,
                            ui_settings.info_boxes.border_style);
 
@@ -257,7 +238,8 @@ LayoutConfigPanel::Save(bool &_changed)
                 ui_settings.info_boxes.inverse))
     require_restart = changed = true;
 
-  if (SaveValue(AppInfoBoxColors, ProfileKeys::AppInfoBoxColors,
+  if (HasColors() &&
+      SaveValue(AppInfoBoxColors, ProfileKeys::AppInfoBoxColors,
                 ui_settings.info_boxes.use_colors))
     require_restart = changed = true;
 
@@ -273,6 +255,12 @@ LayoutConfigPanel::Save(bool &_changed)
       if (!Display::Rotate(ui_settings.display.orientation))
         LogFormat("Display rotation failed");
     }
+
+#ifdef KOBO
+    event_queue->SetMouseRotation(ui_settings.display.orientation);
+#endif
+
+    CommonInterface::main_window->CheckResize();
   } else if (info_box_geometry_changed)
     CommonInterface::main_window->ReinitialiseLayout();
 
