@@ -41,7 +41,6 @@ class TaskCalculatorPanel final
   const bool *task_modified;
 
   fixed emc;
-  fixed cruise_efficiency;
 
 public:
   TaskCalculatorPanel(const DialogLook &look, const bool *_task_modified)
@@ -59,12 +58,6 @@ public:
     return *task_modified;
   }
 
-  void GetCruiseEfficiency();
-
-  void SetCruiseEfficiency(fixed value) {
-    cruise_efficiency = value;
-  }
-
   void Refresh();
 
   /* virtual methods from Widget */
