@@ -32,6 +32,7 @@ Copyright_License {
 #include "UIGlobals.hpp"
 #include "Look/IconLook.hpp"
 #include "Look/MapLook.hpp"
+#include "Look/DialogLook.hpp"
 #include "Dialogs/Message.hpp"
 #include "Screen/Layout.hpp"
 #include "Screen/Key.h"
@@ -65,11 +66,6 @@ struct TaskManagerLayout {
   bool vertical;
 };
 
-/* TODO: eliminate all global variables */
-static TaskManagerDialog *instance;
-static unsigned TurnpointTab = 0;
-static unsigned PropertiesTab = 0;
-
 TaskManagerDialog::~TaskManagerDialog()
 {
   delete task_view;
@@ -78,6 +74,39 @@ TaskManagerDialog::~TaskManagerDialog()
   delete task;
 }
 
+void
+TaskManagerDialog::ReinitialiseLayout(const PixelRect &parent_rc)
+{
+  Move(parent_rc);
+}
+
+bool
+TaskManagerDialog::OnAnyKeyDown(unsigned key_code)
+{
+  if (WndForm::OnAnyKeyDown(key_code) ||
+      tab_bar->InvokeKeyPress(key_code))
+    return true;
+
+  switch (key_code) {
+  case KEY_ESCAPE:
+    if (!modified)
+      /* close the dialog immediately if nothing was modified */
+      return false;
+
+    if (tab_bar->GetCurrentPage() != 4) {
+      /* switch to "close" page instead of closing the dialog */
+      tab_bar->SetCurrentPage(4);
+      tab_bar->FocusCurrentWidget();
+      return true;
+    }
+
+    return false;
+
+  default:
+    return false;
+  }
+}
+
 void
 TaskManagerDialog::OnAction(int id)
 {
@@ -142,7 +171,7 @@ TaskManagerDialog::Create(SingleWindow &parent)
 
   ButtonWindowStyle button_style(hidden);
   button_style.TabStop();
-  target_button = new WndButton(client_area, GetLook(), _("Target"),
+  target_button = new WndButton(client_area, GetLook().button, _("Target"),
                                 layout.target_button, button_style,
                                 *this, TARGET);
 
@@ -173,10 +202,10 @@ TaskManagerDialog::Create(SingleWindow &parent)
     CommonInterface::GetUISettings().dialog.tab_style
     == DialogSettings::TabStyle::Icon;
   const IconLook &icons = UIGlobals::GetIconLook();
-  const Bitmap *CalcIcon = enable_icons ? &icons.hBmpTabCalculator : NULL;
-  const Bitmap *TurnPointIcon = enable_icons ? &icons.hBmpTabTask : NULL;
-  const Bitmap *BrowseIcon = enable_icons ? &icons.hBmpTabWrench : NULL;
-  const Bitmap *PropertiesIcon = enable_icons ? &icons.hBmpTabSettings : NULL;
+  const Bitmap *CalcIcon = enable_icons ? &icons.hBmpTabCalculator : nullptr;
+  const Bitmap *TurnPointIcon = enable_icons ? &icons.hBmpTabTask : nullptr;
+  const Bitmap *BrowseIcon = enable_icons ? &icons.hBmpTabWrench : nullptr;
+  const Bitmap *PropertiesIcon = enable_icons ? &icons.hBmpTabSettings : nullptr;
 
   tab_bar->AddTab(wCalculator, _("Calculator"), CalcIcon);
 
@@ -209,6 +238,27 @@ TaskManagerDialog::Create(SingleWindow &parent)
   UpdateCaption();
 }
 
+void
+TaskManagerDialog::OnResize(PixelSize new_size)
+{
+  WndForm::OnResize(new_size);
+
+  ContainerWindow &client_area = GetClientAreaWindow();
+  const PixelRect rc = client_area.GetClientRect();
+  const TaskManagerLayout layout = CalculateTaskManagerLayout(rc);
+
+  task_view_position = layout.task_view;
+
+  if (task_view != nullptr)
+    task_view->Move(layout.task_view);
+
+  if (target_button != nullptr)
+    target_button->Move(layout.target_button);
+
+  if (tab_bar != nullptr)
+    tab_bar->UpdateLayout(rc, layout.tab_bar, layout.vertical);
+}
+
 void
 TaskManagerDialog::Destroy()
 {
@@ -294,6 +344,7 @@ TaskManagerDialog::Commit()
   if (!modified)
     return true;
 
+  task->UpdateStatsGeometry();
   modified |= task->GetFactory().CheckAddFinish();
 
   if (!task->TaskSize() || task->CheckTask()) {
@@ -305,8 +356,6 @@ TaskManagerDialog::Commit()
       way_points.Optimise();
     }
 
-    task->FillMatPoints(way_points);
-
     protected_task_manager->TaskCommit(*task);
     protected_task_manager->TaskSaveDefault();
 
@@ -332,15 +381,14 @@ TaskManagerDialog::Revert()
 }
 
 void
-dlgTaskManagerShowModal(SingleWindow &parent)
+dlgTaskManagerShowModal()
 {
-  if (protected_task_manager == NULL)
+  if (protected_task_manager == nullptr)
     return;
 
   TaskManagerDialog dialog(UIGlobals::GetDialogLook());
-  instance = &dialog;
 
-  dialog.Create(parent);
+  dialog.Create(UIGlobals::GetMainWindow());
 
   dialog.ShowModal();
   dialog.Destroy();
