@@ -250,6 +250,7 @@ OnRemoveClicked()
   if (!ordered_task->GetFactory().Remove(active_index))
     return;
 
+  ordered_task->UpdateGeometry();
   task_modified = true;
   wf->SetModalResult(mrCancel);
 }
@@ -274,6 +275,7 @@ OnRelocateClicked()
     return;
 
   ordered_task->GetFactory().Relocate(active_index, *wp);
+  ordered_task->UpdateGeometry();
   task_modified = true;
   RefreshView();
 }
@@ -282,6 +284,7 @@ static void
 OnTypeClicked()
 {
   if (dlgTaskPointType(&ordered_task, active_index)) {
+    ordered_task->UpdateGeometry();
     task_modified = true;
     RefreshView();
   }
@@ -315,6 +318,7 @@ static void
 OnOptionalStartsClicked()
 {
   if (dlgTaskOptionalStarts(&ordered_task)) {
+    ordered_task->UpdateGeometry();
     task_modified = true;
     RefreshView();
   }
@@ -368,8 +372,5 @@ dlgTaskPointShowModal(OrderedTask **task,
     *task = ordered_task;
     task_modified = true;
   } 
-  if (task_modified) {
-    ordered_task->UpdateGeometry();
-  }
   return task_modified;
 }
