@@ -23,6 +23,9 @@
 #include "OLCTriangle.hpp"
 #include "Cast.hpp"
 #include "Trace/Trace.hpp"
+#include "Util/QuadTree.hpp"
+
+#include <limits>
 
 /*
  @todo potential to use 3d convex hull to speed search
@@ -76,8 +79,7 @@ OLCTriangle::Reset()
   // this should be adjusted when the trace size is known
   tick_iterations = 1000;
 
-  closing_pairs.clear();
-  search_point_tree.clear();
+  closing_pairs.Clear();
   ClearTrace();
 
   ResetBranchAndBound();
@@ -117,7 +119,7 @@ OLCTriangle::UpdateTrace(bool force)
 
     best_d = 0;
 
-    closing_pairs.clear();
+    closing_pairs.Clear();
     is_closed = FindClosingPairs(0);
 
    } else if (is_complete && incremental) {
@@ -190,7 +192,7 @@ OLCTriangle::SolveTriangle(bool exhaustive)
          closing_pair != closing_pairs.closing_pairs.end();
          ++closing_pair) {
 
-      auto already_relaxed = relaxed_pairs.findRange(*closing_pair);
+      auto already_relaxed = relaxed_pairs.FindRange(*closing_pair);
       if (already_relaxed.first != 0 || already_relaxed.second != 0)
         // this pair is already relaxed... continue with next
         continue;
@@ -198,33 +200,33 @@ OLCTriangle::SolveTriangle(bool exhaustive)
       unsigned relax_first = closing_pair->first;
       unsigned relax_last = closing_pair->second;
 
-      for (auto relaxed = closing_pair;
+      const unsigned max_first = closing_pair->first + relax;
+      const unsigned max_last = closing_pair->second + relax;
+
+      for (auto relaxed = std::next(closing_pair);
            relaxed != closing_pairs.closing_pairs.end() &&
-           relaxed->first <= closing_pair->first + relax &&
-           relaxed->second <= closing_pair->second + relax;
+           relaxed->first <= max_first && relaxed->second <= max_last;
            ++relaxed)
         relax_last = relaxed->second;
 
-      relaxed_pairs.insert(ClosingPair(relax_first, relax_last));
+      relaxed_pairs.Insert(ClosingPair(relax_first, relax_last));
     }
 
     // TODO: reverse sort relaxed pairs according to number of contained points
 
     ClosingPairs close_look;
 
-    for (auto relaxed_pair = relaxed_pairs.closing_pairs.begin();
-         relaxed_pair != relaxed_pairs.closing_pairs.end();
-         ++relaxed_pair) {
+    for (const auto relaxed_pair : relaxed_pairs.closing_pairs) {
 
       std::tuple<unsigned, unsigned, unsigned, unsigned> triangle;
 
-      triangle = RunBranchAndBound(relaxed_pair->first, relaxed_pair->second, best_d, exhaustive);
+      triangle = RunBranchAndBound(relaxed_pair.first, relaxed_pair.second, best_d, exhaustive);
 
       if (std::get<3>(triangle) > best_d) {
         // solution is better than best_d
         // only if triangle is inside a unrelaxed pair...
 
-        auto unrelaxed = closing_pairs.findRange(ClosingPair(std::get<0>(triangle), std::get<2>(triangle)));
+        auto unrelaxed = closing_pairs.FindRange(ClosingPair(std::get<0>(triangle), std::get<2>(triangle)));
         if (unrelaxed.first != 0 || unrelaxed.second != 0) {
           // fortunately it is inside a unrelaxed closing pair :-)
           start = unrelaxed.first;
@@ -237,32 +239,30 @@ OLCTriangle::SolveTriangle(bool exhaustive)
         } else {
           // otherwise we should solve the triangle again for every unrelaxed pair
           // contained inside the current relaxed pair. *damn!*
-          for (auto closing_pair = closing_pairs.closing_pairs.begin();
-               closing_pair != closing_pairs.closing_pairs.end();
-                ++closing_pair) {
-            if (closing_pair->first >= relaxed_pair->first && closing_pair->second <= relaxed_pair->second)
-              close_look.insert(*closing_pair);
+          for (const auto closing_pair : closing_pairs.closing_pairs) {
+            if (closing_pair.first >= relaxed_pair.first &&
+                closing_pair.second <= relaxed_pair.second)
+              close_look.Insert(closing_pair);
          }
        }
       }
     }
 
-    for (auto close_look_pair = close_look.closing_pairs.begin();
-         close_look_pair != close_look.closing_pairs.end();
-         ++close_look_pair) {
-
+    for (const auto &close_look_pair : close_look.closing_pairs) {
       std::tuple<unsigned, unsigned, unsigned, unsigned> triangle;
 
-      triangle = RunBranchAndBound(close_look_pair->first, close_look_pair->second, best_d, exhaustive);
+      triangle = RunBranchAndBound(close_look_pair.first,
+                                   close_look_pair.second,
+                                   best_d, exhaustive);
 
       if (std::get<3>(triangle) > best_d) {
         // solution is better than best_d
 
-        start = close_look_pair->first;
+        start = close_look_pair.first;
         tp1 = std::get<0>(triangle);
         tp2 = std::get<1>(triangle);
         tp3 = std::get<2>(triangle);
-        finish = close_look_pair->second;
+        finish = close_look_pair.second;
 
         best_d = std::get<3>(triangle);
       }
@@ -331,13 +331,18 @@ OLCTriangle::RunBranchAndBound(unsigned from, unsigned to, unsigned worst_d, boo
     // initiate algorithm. otherwise continue unfinished run
     running = true;
 
-    // initialize bound-and-branch tree with root node
-    CandidateSet root_candidates(this, from, to);
-    if (root_candidates.isFeasible(is_fai, large_triangle_check) && root_candidates.df_max >= worst_d)
+    // initialize bound-and-branch tree with root node (note: Candidate set interval is [min, max))
+    CandidateSet root_candidates(this, from, to + 1);
+    if (root_candidates.IsFeasible(is_fai, large_triangle_check) &&
+        root_candidates.df_max >= worst_d)
       branch_and_bound.insert(std::pair<unsigned, CandidateSet>(root_candidates.df_max, root_candidates));
   }
 
-  while (branch_and_bound.size() != 0) {
+  const unsigned max_iterations = !exhaustive && predict
+    ? tick_iterations
+    : std::numeric_limits<unsigned>::max();
+
+  while (!branch_and_bound.empty()) {
     /* now loop over the tree, branching each found candidate set, adding the branch if it's feasible.
      * remove all candidate sets with d_max smaller than d_min of the largest integral candidate set
      * always work on the node with largest d_min
@@ -346,13 +351,15 @@ OLCTriangle::RunBranchAndBound(unsigned from, unsigned to, unsigned worst_d, boo
     iterations++;
 
     // break loop if tick_iterations exceeded
-    if (!exhaustive && predict && iterations > tick_iterations) break;
+    if (iterations > max_iterations)
+      break;
 
     // first clean up tree, removeing all nodes with d_max < worst_d
     branch_and_bound.erase(branch_and_bound.begin(), branch_and_bound.lower_bound(worst_d));
 
     // we might have cleaned up the whole tree. nothing to do then...
-    if (branch_and_bound.size() == 0) break;
+    if (branch_and_bound.empty())
+      break;
 
     /* get node to work on.
      * change node selection strategy if the tree grows too big.
@@ -368,7 +375,8 @@ OLCTriangle::RunBranchAndBound(unsigned from, unsigned to, unsigned worst_d, boo
       node = --branch_and_bound.end();
     }
 
-    if (node->second.df_min >= worst_d && node->second.integral(this, is_fai, large_triangle_check)) {
+    if (node->second.df_min >= worst_d &&
+        node->second.IsIntegral(this, is_fai, large_triangle_check)) {
       // node is integral feasible -> a possible solution
 
       worst_d = node->second.df_min;
@@ -383,16 +391,16 @@ OLCTriangle::RunBranchAndBound(unsigned from, unsigned to, unsigned worst_d, boo
     } else {
       // split largest bounding box of node and create child nodes
 
-      const unsigned tp1_diag = node->second.tp1.diagonal();
-      const unsigned tp2_diag = node->second.tp2.diagonal();
-      const unsigned tp3_diag = node->second.tp3.diagonal();
+      const unsigned tp1_diag = node->second.tp1.GetDiagnoal();
+      const unsigned tp2_diag = node->second.tp2.GetDiagnoal();
+      const unsigned tp3_diag = node->second.tp3.GetDiagnoal();
 
       const unsigned max_diag = std::max({tp1_diag, tp2_diag, tp3_diag});
 
       CandidateSet left, right;
       bool add = false;
 
-      if (tp1_diag == max_diag && node->second.tp1.size() != 1) {
+      if (tp1_diag == max_diag && node->second.tp1.GetSize() != 1) {
         // split tp1 range
         const unsigned split = (node->second.tp1.index_min + node->second.tp1.index_max) / 2;
 
@@ -405,7 +413,7 @@ OLCTriangle::RunBranchAndBound(unsigned from, unsigned to, unsigned worst_d, boo
           right = CandidateSet(TurnPointRange(this, split, node->second.tp1.index_max),
                                node->second.tp2, node->second.tp3);
         }
-      } else if (tp2_diag == max_diag && node->second.tp2.size() != 1) {
+      } else if (tp2_diag == max_diag && node->second.tp2.GetSize() != 1) {
         // split tp2 range
         const unsigned split = (node->second.tp2.index_min + node->second.tp2.index_max) / 2;
 
@@ -420,7 +428,7 @@ OLCTriangle::RunBranchAndBound(unsigned from, unsigned to, unsigned worst_d, boo
                                TurnPointRange(this, split, node->second.tp2.index_max),
                                node->second.tp3);
         }
-      } else if (node->second.tp3.size() != 1) {
+      } else if (node->second.tp3.GetSize() != 1) {
         // split tp3 range
         const unsigned split = (node->second.tp3.index_min + node->second.tp3.index_max) / 2;
 
@@ -437,11 +445,13 @@ OLCTriangle::RunBranchAndBound(unsigned from, unsigned to, unsigned worst_d, boo
 
       if (add) {
         // add the new candidate set only if it it's feasible and has d_min >= worst_d
-        if (left.df_max >= worst_d && left.isFeasible(is_fai, large_triangle_check)) {
+        if (left.df_max >= worst_d &&
+            left.IsFeasible(is_fai, large_triangle_check)) {
           branch_and_bound.insert(std::pair<unsigned, CandidateSet>(left.df_max, left));
         }
 
-        if (right.df_max >= worst_d && right.isFeasible(is_fai, large_triangle_check)) {
+        if (right.df_max >= worst_d &&
+            right.IsFeasible(is_fai, large_triangle_check)) {
           branch_and_bound.insert(std::pair<unsigned, CandidateSet>(right.df_max, right));
         }
       }
@@ -452,7 +462,7 @@ OLCTriangle::RunBranchAndBound(unsigned from, unsigned to, unsigned worst_d, boo
   }
 
 
-  if (branch_and_bound.size() == 0)
+  if (branch_and_bound.empty())
     running = false;
 
   if (integral_feasible) {
@@ -480,13 +490,44 @@ OLCTriangle::CalculateResult() const
   return result;
 }
 
+gcc_pure
+static bool
+IsInRange(const SearchPoint &a, const SearchPoint &b,
+          unsigned half_max_range_sq, fixed max_distance)
+{
+  /* optimisation: if the flat distance is much smaller than the
+     maximum range, we don't need to call the method
+     GeoPoint::Distance() which is very expensive */
+  return a.GetFlatLocation().DistanceSquared(b.GetFlatLocation()) <= half_max_range_sq ||
+    a.GetLocation().Distance(b.GetLocation()) <= max_distance;
+}
+
 bool
 OLCTriangle::FindClosingPairs(unsigned old_size)
 {
   if (predict) {
-    return closing_pairs.insert(ClosingPair(0, n_points-1));
+    return closing_pairs.Insert(ClosingPair(0, n_points-1));
   }
 
+  struct TracePointNode {
+    const TracePoint *point;
+    unsigned index;
+  };
+
+  struct TracePointNodeAccessor {
+    gcc_pure
+    int GetX(const TracePointNode &node) const {
+      return node.point->GetFlatLocation().longitude;
+    }
+
+    gcc_pure
+    int GetY(const TracePointNode &node) const {
+      return node.point->GetFlatLocation().latitude;
+    }
+  };
+
+  QuadTree<TracePointNode, TracePointNodeAccessor> search_point_tree;
+
   for (unsigned i = old_size; i < n_points; ++i) {
     TracePointNode node;
     node.point = &GetPoint(i);
@@ -495,45 +536,49 @@ OLCTriangle::FindClosingPairs(unsigned old_size)
     search_point_tree.insert(node);
   }
 
+  search_point_tree.Optimise();
+
   bool new_pair = false;
 
   for (unsigned i = old_size; i < n_points; ++i) {
-    std::vector<TracePointNode> how_close;
     TracePointNode point;
     point.point = &GetPoint(i);
     point.index = i;
 
-    const unsigned max_range =
-      trace_master.ProjectRange(GetPoint(i).GetLocation(), max_distance);
+    const SearchPoint start = *point.point;
+    const unsigned max_range = trace_master.ProjectRange(start.GetLocation(), max_distance);
+    const unsigned half_max_range_sq = max_range * max_range / 2;
 
-    search_point_tree.find_within_range(point, max_range,
-      std::back_insert_iterator<std::vector<TracePointNode>>(how_close));
-
-    const SearchPoint start = GetPoint(i);
-    const int min_altitude = GetMinimumFinishAltitude(GetPoint(i));
-    const int max_altitude = GetMaximumStartAltitude(GetPoint(i));
+    const int min_altitude = GetMinimumFinishAltitude(*point.point);
+    const int max_altitude = GetMaximumStartAltitude(*point.point);
 
     unsigned last = 0, first = i;
 
-    for (unsigned n = 0; n < how_close.size(); ++n) {
-      const SearchPoint dest = GetPoint(how_close[n].index);
+    const auto visitor = [this, i, start,
+                          half_max_range_sq,
+                          min_altitude, max_altitude,
+                          &first, &last]
+      (const TracePointNode &node) {
+      const auto &dest = *node.point;
 
-      if (how_close[n].index + 2 < i &&
-          GetPoint(how_close[n].index).GetIntegerAltitude() <= max_altitude &&
-          start.GetLocation().Distance(dest.GetLocation()) <= max_distance) {
+      if (node.index + 2 < i &&
+          dest.GetIntegerAltitude() <= max_altitude &&
+          IsInRange(start, dest, half_max_range_sq, max_distance)) {
         // point i is last point
-        first = std::min(how_close[n].index, first);
+        first = std::min(node.index, first);
         last = i;
-      } else if (how_close[n].index > i + 2 &&
-                 GetPoint(how_close[n].index).GetIntegerAltitude() >= min_altitude &&
-                 start.GetLocation().Distance(dest.GetLocation()) <= max_distance) {
+      } else if (node.index > i + 2 &&
+                 dest.GetIntegerAltitude() >= min_altitude &&
+                 IsInRange(start, dest, half_max_range_sq, max_distance)) {
         // point i is first point
         first = i;
-        last = std::max(how_close[n].index, last);
+        last = std::max(node.index, last);
       }
-    }
+    };
 
-    if (last != 0 && closing_pairs.insert(ClosingPair(first, last)))
+    search_point_tree.VisitWithinRange(point, max_range, visitor);
+
+    if (last != 0 && closing_pairs.Insert(ClosingPair(first, last)))
       new_pair = true;
   }
 
