@@ -103,12 +103,23 @@ public:
    */
   bool KeyPress(unsigned key_code);
 
-protected:
+private:
   gcc_pure
-  UPixelScalar Width(unsigned i) const;
+  unsigned Width(unsigned i) const;
+
+  /**
+   * Check how many buttons fit into a row, starting at the given
+   * offset.
+   *
+   * @param start the first button index in this row
+   * @param total_width the total width of the panel in pixels
+   * @return the first button index not in this row
+   */
+  gcc_pure
+  unsigned FitButtonRow(unsigned start, unsigned total_width) const;
 
   gcc_pure
-  UPixelScalar RangeMaxWidth(unsigned start, unsigned end) const;
+  unsigned RangeMaxWidth(unsigned start, unsigned end) const;
 
   PixelRect VerticalRange(PixelRect rc, unsigned start, unsigned end);
 
