@@ -23,7 +23,6 @@
 
 #include "BigTrafficWidget.hpp"
 #include "Dialogs/Traffic/TrafficDialogs.hpp"
-#include "Dialogs/CallBackTable.hpp"
 #include "Math/Screen.hpp"
 #include "Screen/Canvas.hpp"
 #include "Screen/Layout.hpp"
@@ -655,7 +654,10 @@ TrafficWidget::Update()
   const DerivedInfo &calculated = CommonInterface::Calculated();
 
   if (CommonInterface::GetUISettings().traffic.auto_close_dialog &&
-      basic.flarm.traffic.IsEmpty()) {
+      basic.flarm.traffic.IsEmpty() &&
+      /* auto-close only really closes the FLARM radar if the
+         "restored" page has no FLARM radar */
+      PageActions::GetConfiguredLayout().main != PageLayout::Main::FLARM_RADAR) {
     /* this must be deferred, because this method is called from
        within the BlackboardListener, and we must not unregister the
        listener in this context */
@@ -871,22 +873,23 @@ TrafficWidget::Prepare(ContainerWindow &parent, const PixelRect &_rc)
   const PixelRect rc = GetContainer().GetClientRect();
 
 #ifndef GNAV
-  zoom_in_button = new WndSymbolButton(GetContainer(), look.dialog,
+  zoom_in_button = new WndSymbolButton(GetContainer(), look.dialog.button,
                                        _T("+"), rc, ButtonWindowStyle(),
                                        *this, ZOOM_IN);
-  zoom_out_button = new WndSymbolButton(GetContainer(), look.dialog,
+  zoom_out_button = new WndSymbolButton(GetContainer(), look.dialog.button,
                                         _T("-"), rc, ButtonWindowStyle(),
                                         *this, ZOOM_OUT);
-  previous_item_button = new WndSymbolButton(GetContainer(), look.dialog,
+  previous_item_button = new WndSymbolButton(GetContainer(),
+                                             look.dialog.button,
                                              _T("<"), rc, ButtonWindowStyle(),
                                              *this, PREVIOUS_ITEM);
-  next_item_button = new WndSymbolButton(GetContainer(), look.dialog,
+  next_item_button = new WndSymbolButton(GetContainer(), look.dialog.button,
                                          _T(">"), rc, ButtonWindowStyle(),
                                          *this, NEXT_ITEM);
-  details_button = new WndButton(GetContainer(), look.dialog,
+  details_button = new WndButton(GetContainer(), look.dialog.button,
                                  _("Details"), rc, ButtonWindowStyle(),
                                  *this, DETAILS);
-  close_button = new WndButton(GetContainer(), look.dialog,
+  close_button = new WndButton(GetContainer(), look.dialog.button,
                                _("Close"), rc, ButtonWindowStyle(),
                                *this, CLOSE);
 #endif
