@@ -23,7 +23,6 @@ Copyright_License {
 
 #include "MapWindow.hpp"
 #include "Screen/Icon.hpp"
-#include "Look/Fonts.hpp"
 #include "Geo/Math.hpp"
 #include "Task/ProtectedTaskManager.hpp"
 #include "Engine/Task/Ordered/OrderedTask.hpp"
@@ -35,7 +34,6 @@ Copyright_License {
 #include "Look/MapLook.hpp"
 
 #include <stdio.h>
-#include <math.h>
 
 void
 MapWindow::DrawTask(Canvas &canvas)
@@ -71,6 +69,7 @@ MapWindow::DrawTask(Canvas &canvas)
                           task_manager->GetOrderedTask().GetTaskProjection(),
                           ozv, draw_bearing, target_visibility,
                           Basic().location_available, Basic().location);
+    tpv.SetTaskFinished(Calculated().task_stats.task_finished);
     TaskRenderer dv(tpv, render_projection.GetScreenBounds());
     dv.Draw(*task);
   }
@@ -127,7 +126,7 @@ MapWindow::DrawTaskOffTrackIndicator(Canvas &canvas)
 
   GeoPoint start = Basic().location;
   
-  canvas.Select(Fonts::map_bold);
+  canvas.Select(*look.overlay_font);
   canvas.SetTextColor(COLOR_BLACK);
   canvas.SetBackgroundTransparent();
   
