@@ -45,7 +45,7 @@ MakeAirspaceSettingName(char *buffer, const char *prefix, unsigned n)
  * @see Load(unsigned, AirspaceClassRendererSettings &)
  */
 static bool
-GetAirspaceColor(unsigned i, Color &color)
+GetAirspaceColor(unsigned i, RGB8Color &color)
 {
   char name[64];
   MakeAirspaceSettingName(name, "Colour", i);
@@ -75,7 +75,7 @@ Profile::Load(AirspaceRendererSettings &settings)
   GetEnum(ProfileKeys::AltMode, settings.altitude_mode);
   Get(ProfileKeys::ClipAlt, settings.clip_altitude);
 
-#ifndef ENABLE_OPENGL
+#if defined(HAVE_HATCHED_BRUSH) && defined(HAVE_ALPHA_BLEND)
   Get(ProfileKeys::AirspaceTransparency, settings.transparency);
 #endif
 
@@ -129,6 +129,7 @@ Profile::Load(AirspaceComputerSettings &settings)
   Get(ProfileKeys::AltMargin, settings.warnings.altitude_warning_margin);
   Get(ProfileKeys::WarningTime, settings.warnings.warning_time);
   Get(ProfileKeys::AcknowledgementTime, settings.warnings.acknowledgement_time);
+  Get(ProfileKeys::RepetitiveSound, settings.warnings.repetitive_sound);
 
   char name[64];
   unsigned value;
@@ -164,7 +165,7 @@ Profile::SetAirspaceBorderWidth(unsigned i, unsigned border_width)
 }
 
 void
-Profile::SetAirspaceBorderColor(unsigned i, const Color &color)
+Profile::SetAirspaceBorderColor(unsigned i, const RGB8Color &color)
 {
   char name[64];
   MakeAirspaceSettingName(name, "AirspaceBorderColor", i);
@@ -172,7 +173,7 @@ Profile::SetAirspaceBorderColor(unsigned i, const Color &color)
 }
 
 void
-Profile::SetAirspaceFillColor(unsigned i, const Color &color)
+Profile::SetAirspaceFillColor(unsigned i, const RGB8Color &color)
 {
   char name[64];
   MakeAirspaceSettingName(name, "AirspaceFillColor", i);
