@@ -29,7 +29,6 @@ Copyright_License {
 #include "Look/FinalGlideBarLook.hpp"
 #include "Look/TaskLook.hpp"
 #include "Formatter/UserUnits.hpp"
-#include "Util/Macros.hpp"
 
 #ifdef ENABLE_OPENGL
 #include "Screen/OpenGL/Scope.hpp"
@@ -42,7 +41,7 @@ FinalGlideBarRenderer::Draw(Canvas &canvas, const PixelRect &rc,
                             const bool final_glide_bar_mc0_enabled) const
 {
 #ifdef ENABLE_OPENGL
-  const GLEnable blend(GL_BLEND);
+  const GLBlend blend(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
 #endif
 
   RasterPoint GlideBar[6] = {
