@@ -34,6 +34,14 @@ gcc_const
 const char *
 FindDefaultBoldFont();
 
+gcc_const
+const char *
+FindDefaultItalicFont();
+
+gcc_const
+const char *
+FindDefaultBoldItalicFont();
+
 gcc_const
 const char *
 FindDefaultMonospaceFont();
