@@ -26,8 +26,8 @@ Copyright_License {
 
 #ifdef ANDROID
 #include "Screen/Android/Key.h"
-#elif defined(USE_EGL)
-#include "Screen/EGL/Key.h"
+#elif defined(USE_CONSOLE) || defined(NON_INTERACTIVE)
+#include "Screen/FB/Key.h"
 #elif defined(ENABLE_SDL)
 #include "Screen/SDL/Key.h"
 #else
